tonalitytools.chord_class_extent_to_extent_name
===============================================

.. autofunction:: abjad.tools.tonalitytools.chord_class_extent_to_extent_name.chord_class_extent_to_extent_name
